pub fn format_document_with_report(
doc: &Document,
opts: &FmtOptions,
) -> (String, FormatReport)Expand description
Format a parsed document and return aggregate rewrite metrics.
pub fn format_document_with_report(
doc: &Document,
opts: &FmtOptions,
) -> (String, FormatReport)Format a parsed document and return aggregate rewrite metrics.