pub fn format_source(
source: &str,
opts: &FmtOptions,
) -> Result<String, FormatError>Expand description
Parse and format Markdown source with default parse options.
Errors
Returns FormatError::Parse if source parsing fails.
pub fn format_source(
source: &str,
opts: &FmtOptions,
) -> Result<String, FormatError>Parse and format Markdown source with default parse options.
Returns FormatError::Parse if source parsing fails.