format_validated_with_report

Function format_validated_with_report 

pub fn format_validated_with_report(
    doc: &Document,
    opts: &FmtOptions,
) -> Result<(String, FormatReport), FormatError>
Format, return aggregate metrics, and verify that a second pass is semantically stable.

Errors

Returns an error if formatting the output a second time produces a different canonical event stream.