semantically_equivalent

Function semantically_equivalent 

pub fn semantically_equivalent(
    source: &str,
    formatted: &str,
) -> Result<bool, ParseError>
True iff the two Markdown sources parse to the same canonical document signature under default recognition policy.

Errors

Returns ParseError if either input cannot be parsed safely.