pub fn format_validated(
doc: &Document,
opts: &FmtOptions,
) -> Result<String, FormatError>Expand description
Format and verify that a second pass is semantically stable.
Errors
Returns an error if formatting the output a second time produces a different canonical event stream.