pub struct FormatReport {
pub rewrite_candidates: usize,
pub rewrite_committed: usize,
pub rewrite_committed_wrap: usize,
pub rewrite_committed_style: usize,
pub rewrite_rejected_overlap: usize,
pub rewrite_rejected_verification: usize,
pub rewrite_rejected_convergence: usize,
pub rewrite_skipped_wrap: usize,
}Expand description
Aggregate formatter rewrite counts.
The report is intentionally coarse: it exposes whether rewrite transactions are being attempted, committed, or rejected without exposing candidates, owners, snapshots, or parser internals.
Fields
rewrite_candidates: usizerewrite_committed: usizerewrite_committed_wrap: usizerewrite_committed_style: usizerewrite_rejected_overlap: usizerewrite_rejected_verification: usizerewrite_rejected_convergence: usizerewrite_skipped_wrap: usizeTrait Implementations
Sourceimpl Clone for FormatReport
impl Clone for FormatReport
Sourcefn clone(&self) -> FormatReport
fn clone(&self) -> FormatReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FormatReport
impl Debug for FormatReport
Sourceimpl Default for FormatReport
impl Default for FormatReport
Sourcefn default() -> FormatReport
fn default() -> FormatReport
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for FormatReport
impl PartialEq for FormatReport
Sourcefn eq(&self, other: &FormatReport) -> bool
fn eq(&self, other: &FormatReport) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for FormatReport
impl StructuralPartialEq for FormatReport